pub struct StdinRelay { /* private fields */ }Expand description
epoll-based event multiplexer for stdin, SIGWINCH, and shutdown. Linux equivalent of macOS kqueue-based StdinRelay.
Implementations
Sourceimpl StdinRelay
impl StdinRelay
Sourcepub fn new(stdin_fd: RawFd) -> Option<(StdinRelay, ShutdownSignal)>
pub fn new(stdin_fd: RawFd) -> Option<(StdinRelay, ShutdownSignal)>
Create a new relay watching the given stdin fd.
Sourcepub fn wait(&self) -> StdinEvent
pub fn wait(&self) -> StdinEvent
Block until stdin is readable, a resize signal arrives, or shutdown is signaled.